/*
 * Simple library for string transliterateion between English and
 * Berndese languages.
 *
 * Usage:
 * var berndese = new Berndese();
 * var result = berndese.translate("english", "string");
 */


class Berndese {
    constructor() {
        // Translation tables
        this.maps = {
            'berndese': {
                'bk^k': 'q',
                'k^k': 'w',
                'zbr': 'x',
                'z^k': 'y',
                ee: 'th',
                aa: 'ng',
                noo: 'ch',
                oo: 'sh',
                p: 'ph',
                p: 'f',
                b: 'k',
                b: 'c',
                q: 'a',
                z: 'e',
                x: 'i',
                j: 'o',
                k: 'u',
                v: 'b',
                w: 'd',
                m: 'g',
                g: 'h',
                c: 'j',
                f: 'l',
                l: 'm',
                d: 'n',
                h: 'p',
                s: 'r',
                r: 's',
                n: 't',
                t: 'v',
                i: 'z',
                '^': '^'
            },
            'english': {}
        };

        Object.keys(this.maps.berndese).forEach((k) => {
            this.maps.english[this.maps.berndese[k]] = k;
        });

        // Create replace regexes
        this.regexes = {};
        Object.keys(this.maps).forEach((lang) => {
            this.regexes[lang] = new RegExp(
                Object.keys(this.maps[lang]).map((c) => {
                    if (c.indexOf('^') !== -1)
                        return c.replace('\^', '\\^');
                    return c;
                }).join('|'),
                'gi'
            );
        });
    }

    // Get an array of language names
    get languages() {
        return Object.keys(this.maps);
    }

    // Translate string from language
    translate(fromLang, string) {
        return string.replace(this.regexes[fromLang], (c) => {
            if (this.maps[fromLang].hasOwnProperty(c))
                return this.maps[fromLang][c];
            return '';
        });
    }
}
